# Summary of 1 files

## Hlt1Corruption

```
HltSelRepRBStdInfo fails integrity check
```

The file was probably corrupted in HLT1 is not recoverable.

See https://gitlab.cern.ch/lhcb/Allen/-/issues/534.

| Transform | LFN | Job ID | Site | Peak Mem | Log URL(s) |
| --------- | --- | ------ | ---- | -------- | ---------- |
| `250929` | `LFN:/lhcb/LHCb/Collision24/TURCAL_PERSISTRECO.DST/00226360/0000/00226360_00006800_1.turcal_persistreco.dst` | 980612192 | LCG.Manchester.uk | 2.4 GiB | [here](https://lhcb-productions.web.cern.ch/logs/?lfn=%2Flhcb%2FLHCb%2FCollision24%2FLOG%2F00250929%2F0000&task_name=00002288) |
